==> jmax-4.0.0.tar.gz: jmax-4.0.0/packages/sequence/java/ircam/jmax/editors/sequence/tools/SequenceTools.java <==
//
// jMax
// Copyright (C) 1994, 1995, 1998, 1999 by IRCAM-Centre Georges Pompidou, Paris, France.
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// See file LICENSE for further informations on licensing terms.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// Based on Max/ISPW by Miller Puckette.
//
// Authors: Maurizio De Cecco, Francois Dechelle, Enzo Maggi, Norbert Schnell.
// 

package ircam.jmax.editors.sequence.tools;

import ircam.jmax.editors.sequence.*;

import ircam.jmax.toolkit.*;
import ircam.jmax.*;
import java.io.*;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;

/**
 * The class containing the Tools used by a Sequence editor.
 * This class separates the ToolManager functionalities 
 * of the SequenceToolManager by the knowledge of the tools */
public class SequenceTools implements ToolProvider{

  public SequenceTools()
  {
    String path = null;
    String fs = File.separator;
    /*
      WARNING:
      Waiting for a method to get the packagePath from the package name
    */
    /*try
      {
      path  = MaxApplication.getPackageHandler().locatePackage("sequence").getPath()+fs+"images"+fs;
      }
      catch(FileNotFoundException e){
      path = JMaxApplication.getProperty("sequencePackageDir")+File.separator+"images"+File.separator;
      }*/
    path = JMaxApplication.getProperty("jmaxRoot")+fs+"packages"+fs+"sequence"+fs+"images"+fs;//??????????????????	 
    /*************************************************************/

    tools[0] = new ArrowTool(new ImageIcon(path+"arrow.gif"));
    tools[1] = new AdderTool(new ImageIcon(path+"edit.gif"));
    tools[2] = new DeleteTool(new ImageIcon(path+"delete.gif"));
    tools[3] = new ResizerTool(new ImageIcon(path+"hresize.gif"));
    tools[4] = new VResizerTool(new ImageIcon(path+"vresize.gif"));
    tools[5] = new ZoomTool(new ImageIcon(path+"zoomer.gif"));
    tools[6] = new ScrollerTool(new ImageIcon(path+"scroller.gif"));
    tools[7] = new LinerTool(new ImageIcon(path+"liner.gif"));
    tools[8] = new CombTool(new ImageIcon(path+"comber.gif"));
  }

  public Enumeration getTools()
  {
    return new ToolEnumeration();
  }

  class ToolEnumeration implements Enumeration 
  {
    ToolEnumeration()
    {
      index = 0;
    }
    
    public boolean hasMoreElements()
    {
      return index < instance.tools.length;
    }
    
    public Object nextElement()
    {
      return instance.tools[index++];
    }
    
    //---
    int index;
  }

  //---
  Tool tools[] = new Tool[9];
  public static SequenceTools instance = new SequenceTools();
}

==> jmax-4.1.0.tar.gz: jmax-4.1.0/packages/sequence/java/ircam/jmax/editors/sequence/tools/SequenceTools.java <==
//
// jMax
// Copyright (C) 1994, 1995, 1998, 1999 by IRCAM-Centre Georges Pompidou, Paris, France.
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public License
// as published by the Free Software Foundation; either version 2.1
// of the License, or (at your option) any later version.
// 
// See file COPYING.LIB for further informations on licensing terms.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 

package ircam.jmax.editors.sequence.tools;

import ircam.jmax.editors.sequence.*;

import ircam.jmax.toolkit.*;
import ircam.jmax.*;
import java.io.*;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;

/**
 * The class containing the Tools used by a Sequence editor.
 * This class separates the ToolManager functionalities 
 * of the SequenceToolManager by the knowledge of the tools */
public class SequenceTools implements ToolProvider{

  public SequenceTools()
  {
    String path = null;
    String fs = File.separator;
 
    path = JMaxApplication.getProperty("jmaxRoot")+fs+"packages"+fs+"sequence"+fs+"images"+fs;//??????????????????	 
    
    tools = new Tool[1];

    tools[0] = new ArrowTool(new ImageIcon(path+"arrow.gif"));
  }

  public Enumeration getTools()
  {
    return new ToolEnumeration( this);
  }

  class ToolEnumeration implements Enumeration 
  {
    ToolEnumeration( SequenceTools sq)
    {
      index = 0;
      sequenceTools = sq;
    }
    
    public boolean hasMoreElements()
    {
      return index < sequenceTools.tools.length;
    }
    
    public Object nextElement()
    {
      return sequenceTools.tools[index++];
    }
    
    //---
    int index;
    SequenceTools sequenceTools;
  }

  //---
  Tool tools[];
  public static SequenceTools instance = new SequenceTools();
}
